import Link from "next/link"
import Image from "next/image"
import { notFound } from "next/navigation"
import anderlechtData from "@/data/parcours/anderlecht.json"

// Cette fonction est appelée lors du rendu de la page
export default function ParcoursDetailPage({ params }: { params: { id: string } }) {
  // Récupérer l'ID du parcours depuis les paramètres de l'URL
  const { id } = params

  // Pour l'instant, nous n'avons que les données pour Anderlecht
  if (id !== "anderlecht") {
    // Si l'ID n'est pas "anderlecht", renvoyer une page 404
    notFound()
  }

  // Utiliser les données d'Anderlecht
  const itineraires = anderlechtData

  return (
    <div className="container mx-auto px-4 py-8">
      <div className="mb-6">
        <Link href="/parcours" className="text-blue-600 hover:underline">
          ← Retour aux parcours
        </Link>
      </div>

      <h1 className="text-3xl font-bold mb-6">Parcours d'examen à Anderlecht</h1>
      <p className="text-lg mb-8">Découvrez les différents itinéraires d'examen pratique à Anderlecht.</p>

      <div className="space-y-8">
        {itineraires.map((itineraire, index) => (
          <div key={index} className="bg-white rounded-lg shadow-md overflow-hidden">
            <div className="md:flex">
              <div className="md:w-1/3 relative h-64 md:h-auto">
                <Image
                  src={itineraire.image || "/placeholder.svg"}
                  alt={`${itineraire.title} - ${itineraire.subtitle}`}
                  width={400}
                  height={300}
                  className="object-cover w-full h-full"
                />
              </div>
              <div className="p-6 md:w-2/3">
                <h2 className="text-2xl font-bold mb-4">
                  {itineraire.title} - {itineraire.subtitle}
                </h2>

                <div className="grid grid-cols-1 md:grid-cols-3 gap-4 mb-6">
                  <div>
                    <p className="text-sm text-gray-600">Durée</p>
                    <p className="font-medium">{itineraire.duration}</p>
                  </div>
                  <div>
                    <p className="text-sm text-gray-600">Distance</p>
                    <p className="font-medium">{itineraire.distance}</p>
                  </div>
                  <div>
                    <p className="text-sm text-gray-600">Difficulté</p>
                    <p className="font-medium">{itineraire.difficulty}/40</p>
                  </div>
                </div>

                <a
                  href={itineraire.startLink}
                  target="_blank"
                  rel="noopener noreferrer"
                  className="inline-block px-4 py-2 bg-blue-600 text-white rounded-md hover:bg-blue-700"
                >
                  Voir sur Google Maps
                </a>
              </div>
            </div>
          </div>
        ))}
      </div>
    </div>
  )
}
